---
title: grafana
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.grafana) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.grafana?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.grafana) [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg?label=license)](https://gitea.rknet.org/ansible/xoxys.grafana/src/branch/main/LICENSE) 

Setup [Grafana](https://grafana.com) observability platform.

* [Default Variables](#default-variables)
  * [grafana_admin_password](#grafana_admin_password)
  * [grafana_admin_user](#grafana_admin_user)
  * [grafana_auth_providers](#grafana_auth_providers)
  * [grafana_bind_ip](#grafana_bind_ip)
  * [grafana_bind_port](#grafana_bind_port)
  * [grafana_cache_provider](#grafana_cache_provider)
  * [grafana_cache_provider_config](#grafana_cache_provider_config)
  * [grafana_data_dir](#grafana_data_dir)
  * [grafana_datasource_files](#grafana_datasource_files)
  * [grafana_db_name](#grafana_db_name)
  * [grafana_db_password](#grafana_db_password)
  * [grafana_db_port](#grafana_db_port)
  * [grafana_db_server](#grafana_db_server)
  * [grafana_db_ssl_mode](#grafana_db_ssl_mode)
  * [grafana_db_type](#grafana_db_type)
  * [grafana_db_user](#grafana_db_user)
  * [grafana_instance_name](#grafana_instance_name)
  * [grafana_listen_address](#grafana_listen_address)
  * [grafana_log_dir](#grafana_log_dir)
  * [grafana_log_level](#grafana_log_level)
  * [grafana_log_mode](#grafana_log_mode)
  * [grafana_log_providers](#grafana_log_providers)
  * [grafana_packages_extra](#grafana_packages_extra)
  * [grafana_plugin_dir](#grafana_plugin_dir)
  * [grafana_secret_key](#grafana_secret_key)
  * [grafana_smtp_from](#grafana_smtp_from)
  * [grafana_smtp_from_name](#grafana_smtp_from_name)
  * [grafana_smtp_host](#grafana_smtp_host)
  * [grafana_smtp_password](#grafana_smtp_password)
  * [grafana_smtp_port](#grafana_smtp_port)
  * [grafana_smtp_username](#grafana_smtp_username)
* [Dependencies](#dependencies)

---

## Default Variables

### grafana_admin_password

#### Default value

```YAML
grafana_admin_password: secure
```

### grafana_admin_user

#### Default value

```YAML
grafana_admin_user: admin
```

### grafana_auth_providers

#### Default value

```YAML
grafana_auth_providers: []
```

### grafana_bind_ip

#### Default value

```YAML
grafana_bind_ip: 127.0.0.1
```

### grafana_bind_port

#### Default value

```YAML
grafana_bind_port: 61000
```

### grafana_cache_provider

Either `redis`, `memcached' or `database`.

#### Default value

```YAML
grafana_cache_provider: database
```

### grafana_cache_provider_config

Cache connection string options: - database: Will use Grafana primary database. - redis: Config like redis server e.g. `addr=127.0.0.1:6379,pool_size=100,db=0,ssl=false`. Only addr is required. ssl may be 'true', 'false', or 'insecure'. - memcache: `127.0.0.1:11211`

#### Default value

```YAML
grafana_cache_provider_config: _unset_
```

### grafana_data_dir

#### Default value

```YAML
grafana_data_dir: /var/lib/grafana
```

### grafana_datasource_files

#### Default value

```YAML
grafana_datasource_files:
  - grafana/datasources/*.yml.j2
```

### grafana_db_name

#### Default value

```YAML
grafana_db_name: grafana
```

### grafana_db_password

#### Default value

```YAML
grafana_db_password: secure
```

### grafana_db_port

#### Default value

```YAML
grafana_db_port: 5432
```

### grafana_db_server

#### Default value

```YAML
grafana_db_server: localhost
```

### grafana_db_ssl_mode

#### Default value

```YAML
grafana_db_ssl_mode: disable
```

### grafana_db_type

Database provider to use. Available options are `mysql`, 'postgres' and `sqlite3`. Extended configuration options are only applies to non-sqlite provider.

#### Default value

```YAML
grafana_db_type: sqlite3
```

### grafana_db_user

#### Default value

```YAML
grafana_db_user: pggrafana
```

### grafana_instance_name

#### Default value

```YAML
grafana_instance_name: grafana
```

### grafana_listen_address

#### Default value

```YAML
grafana_listen_address: http://localhost
```

### grafana_log_dir

#### Default value

```YAML
grafana_log_dir: /var/log/grafana
```

### grafana_log_level

#### Default value

```YAML
grafana_log_level: info
```

### grafana_log_mode

#### Default value

```YAML
grafana_log_mode:
  - console
  - file
```

### grafana_log_providers

#### Default value

```YAML
grafana_log_providers: []
```

### grafana_packages_extra

#### Default value

```YAML
grafana_packages_extra: []
```

### grafana_plugin_dir

#### Default value

```YAML
grafana_plugin_dir: '{{ grafana_data_dir }}/plugins'
```

### grafana_secret_key

Should be replaced by your own secret.

#### Default value

```YAML
grafana_secret_key: 1234567ABCDEFG
```

### grafana_smtp_from

#### Default value

```YAML
grafana_smtp_from: grafana@localhost
```

### grafana_smtp_from_name

#### Default value

```YAML
grafana_smtp_from_name: Grafana
```

### grafana_smtp_host

#### Default value

```YAML
grafana_smtp_host: _unset_
```

### grafana_smtp_password

#### Default value

```YAML
grafana_smtp_password: _unset_
```

### grafana_smtp_port

#### Default value

```YAML
grafana_smtp_port: 587
```

### grafana_smtp_username

#### Default value

```YAML
grafana_smtp_username: _unset_
```

## Dependencies

None.
